bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 13. Aventiure
___________________________________________________ #### <Wie si ze der hohzit fvrn>
| ### lle> ir vnmuoze lazen wir nv sin ### vnd sagen wie vro Kiemhilt vnd ir magedin ### hin gen Rine fvoren von Niblvnge lant ### nie getrvogen moere so manic herlich gewant ### Vil der sovmschrine man schihte zvo den wegen [30a] ### do reit mit sinen frivnden Sifrit der degen ### vnd div kvniginne dar si heten vrovden <wan> ### sit wart ez in allen ze grozem leide getan
###### 723 | ### Da heime si do liezen Syfrides kindelin ### vnd den svn Kriemhilde daz muoz et also sin ### von ir houereise wuos vil michel ser ### sin vater vn– sin muoter gesach daz kindel nimmer mer
###### 724 | ### Do reit ovch mit in dannen der herre Sigmunt ### sold er rehte <wizzen> wie ez nach der stunt ### zer hochzit ergienge er het ir niht gesehen ### im kvnde an lieben frivnden leider nimmer gescehen
###### 725 | ### Boten man fvr sande die mære siten dar ### do reit ovch in enkegne mit wunderlicher schar ### vil der Vten vrivnde vnd der Gvnthers man ### der wirt gen sinen gesten sich sere vlizen began
###### 726 | ### Er gie zuo Prunhilde da er si sicen vant ### wie enpfieng ivch min swester do ir komt in daz lant ### sam svlt ir enphahen Sifrides wip ### daz tuon ich sprach si gerne von schvlden holt ist ir min lip
###### 727 | ### Do sprach der kvnich riche si koment vns morgen vrvo ### welt ir si enpfahen da grifet balde zvo ### daz wir ir niht biten in der burch hie ### mir sint in allen ziten lieber geste komen nie
###### 728 | ### Ir meide vnd ir vrowen hiez si sa cehant ### suochen guotiv kleider div hesten div man vant ### div ir ingesinde vor gesten solde tragen ### daz taten si doch gerne daz mach man lihte gesagen
###### 729 | ### Ovch ilten do dienen die Gvnthers man ### alle sinen reken der wirt zuo im gewan ### do reit div kvniginne herlichen dan ### da wart vil michel gruozen die lieben geste getan
###### 730 | ### Mit wie getanen vrovden man die geste enphie ### si dvhte daz vrov Kriemhilt vrovn Prvnhilde nie ### so rehte wol enphienge in Burgonden lant ### die ez ie gesahen den wart vil hoher muot bekant
###### 731 | ### Nv was ovch komen Sifrit mit den sinen man ### sach die helde wenden wider vn– dan ### des veldes allenthalben mit vngefuegen scharn ### dringen vn– stovben kvnde niemen da bewarn
###### 732 | ### Do der wirt des landes Sifriden sach ### vnd ovch Sigmvnden wie minneclichen er sprach ### nv sit <mir> groze willekomen vnd al den frivnden min ### iwer hovereise suln wir hohes muotes sin
###### 733 | ### Nv lon iv got sprach Sigmvnt der ere gernde man ### sit daz ivch Sifrit ce frivnde gewan ### do rieten mine sinne daz ich iv wolde sehen ### do sprach der kvnich Gvnther nv ist mir liebe dran geschehen
###### 734 | ### Sifrit wart enphangen als im daz wol gezaz ### mit vil grozen eren nimen was im gram ### des half mit grozen zvhten Giselher vnd Gernot [30b] ### nie lieben gesten man so guotlich erbot
###### 735 | ### Nv naheten zuo an ander der zweier kvnige wip ### da wart vil setel lere maniger vrowen lip ### wart von helden handen erhaben vf daz gras ### die vrovwen gerne dienden waz der da vnmvozech was
###### 736 | ### Do giengen zvo an ander div minnechlichen wip ### des was in grozen vrovden maniges riters lip ### daz ir beider gruozen so minneclich ergie ### do sach man vil der reken der dienen vrovwen da niht lie
###### 737 | ### Daz herlich gesinde vie si bi der hant ### in zvhten groz nigen des man vil da vant ### vnd kvssen minneclichen von vrowen wolgetan ### daz was liep ze sehenne Gvnther vnd Sifride man
###### 738 | ### Si biten da niht langer si riten zuo der stat ### der wirt sinen gesten wol erzeigen bat ### daz man si gerne sehe in Burgonden lant ### manigen puneiz richen man vor den ivnchfrovwen vant
###### 739 | ### Vzer Troni Hagne vnd ovch Ortwin ### daz si gewaltech weren daz taten si wol schün ### swaz si gebieten wolden des torste man niht lan ### von in wart michel dienst den lieben gesten getan
###### 740 | ### Vil schilde horte man hellen da ce dem burge tor ### von stiche vnd von stozen lange habte da vor ### der wirt mit sinen gesten ê si chomen drin ### ia gie in div stunde mit grozer zvrzwile hin
###### 741 | ### Fvr den palas witen mit frovden si do riten ### manigen phelle spehe gvot vn– wol gesniten ### sach man vber setele den vrowen wolgetan ### allenthalben hangen do komen Gvnthers man
###### 742 | ### Die geste hiez man fueren balde an ir gemach ### vnder wilen bliken man Prvnhilde sach ### an vrovwen Kriemhilde div schoene was genuoch ### ir varwe gen dem golde den glanz vil herlichen truoch
###### 743 | ### Allenthalben schallen ze Wormz in der stat ### horte man daz gesinde Gvnther do bat ### Danchwarten sinen marschalch daz er ir solde pflegen ### do begvnde er daz gesinde harte guotlichen legen
###### 744 | ### Dar zuo vnd ovch dar inne spisen man si lie ### ia wart vremder geste baz gepflegen nie ### alles des si gerten des was man in bereit ### der kvnich was so riche daz nieman da niht wart verseit
###### 745 | ### Man diende in frivntliche vnd an allen haz ### der wirt da ze tische mit sinen gesten saz ### man bat Sifriden sicen als er ê hete getan ### do gie mit im ze sedele vil manich <wertlicher> man
###### 746 | ### Zwelf hvndert reken an dem ringe sin ### da ze tische sazen Prvnhilt div kvnigin ### gedaht daz eigen holde nit richer kvnde wesen ### si was im noch so wege daz si in gerne lie genesen
###### 747 | ### An eime abende da der kvnich saz [31a] ### vil der richen kleider wart von wine naz ### da die schenchen solden zuo den tischen gan ### da wart vil voller dienst mit grozem flize getan
###### 748 | ### So man ce hochciten lange hat gepflegen ### vrowen vnde meide hiez man schoene legen ### swannen si dar komen der wirt in willen trvoc ### in guotlichen eren man gap in allen genuoc
###### 749 | ### Do div naht het ende vnd der tac erschein ### vz den sovmschrinen manich edel stein ### erlvhte in guoter wete die fuorte vrovwen hant ### do wart er fur gesvochet manich herlich gewant
###### 750 | ### ê ez wol ertagete do komen fvr den sal ### vil riter vnd knehte do hvop sich aber <schal> ### vor einer vruomesse die man dem kvnige sanch ### da riten ivnge helde daz ins der kvnich seite danch
###### 751 | ### Manic pusune lûte vil krefteclich erdoz ### von trvnben vnd von vloiten der schal wart so groz ### daz Wurmez div vil wite darnach lute erschal ### die hoch gemuoten helde ce rossen komen vber al
###### 752 | ### Do huop sich in dem lande harte hohe ein spil ### von manigem guoten reken der sach man da vil ### den ir tvmbiv herze gaben hohen muot ### der sach man vnder schilde manigen zieren riter guot
###### 753 | ### In div venstersazen div herlichen wip ### vnd vil der schoenen meide geciert was ir lip ### si sahen zvrzewile von manigen kuenen man ### der wirt mit sinen vrivnden selbe riten da began
###### 754 | ### Svs vertriben si di wile div dvhte niht lanch ### man horte da zem tuome manigem gloken klanch ### do komen in die moere die vrowen riten dan ### den edelen kvniginnen volgete manich kuene man
###### 755 | ### Si stuonden vor dem mvnster nider vf daz gras ### Prvnhilt ir gesten dannoch wege was ### si giengen vnder krone in daz mvnster wit ### div liebe wart sit gescheiden daz schuof grozlicher nit
###### 756 | ### Do si gehorten messe si fuoren wider dan ### mit vil manigen ern man sach si sider gan ### ce tische vroliche ir vrovde nie gelach ### da zer hohgezite vnz an den einliften tach

<<< Übersicht <<< vorige Seite nächste Seite >>>